@@ -39,13 +39,6 @@ struct _EphySnapshotService {
 
 G_DEFINE_TYPE (EphySnapshotService, ephy_snapshot_service, G_TYPE_OBJECT)
 
-enum {
-  SNAPSHOT_SAVED,
-  LAST_SIGNAL
-};
-
-static guint signals[LAST_SIGNAL];
-
 typedef enum {
   SNAPSHOT_STALE,
   SNAPSHOT_FRESH
@@ -66,24 +59,6 @@ snapshot_path_cached_data_free (SnapshotPathCachedData *data)
 static void
 ephy_snapshot_service_class_init (EphySnapshotServiceClass *klass)
 {
-  GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-  /**
-   * EphySnapshotService::snapshot-saved:
-   * @url: the URL the snapshot was saved for
-   * @mtime: the mtime embedded in the snapshot, needed to retrieve it
-   *
-   * The ::snapshot-saved signal is emitted when a new snapshot is saved.
-   **/
-  signals[SNAPSHOT_SAVED] = g_signal_new ("snapshot-saved",
-                                          G_OBJECT_CLASS_TYPE (object_class),
-                                          G_SIGNAL_RUN_LAST,
-                                          0,
-                                          NULL, NULL, NULL,
-                                          G_TYPE_NONE,
-                                          2,
-                                          G_TYPE_STRING | G_SIGNAL_TYPE_STATIC_SCOPE,
-                                          G_TYPE_INT64);
 }
 
 static void
@@ -596,28 +571,6 @@ got_snapshot_for_url (EphySnapshotService *service,
   ephy_snapshot_service_take_from_webview (task);
 }
 
-/* We want to return an existing snapshot immediately, even if it is stale,
- * because snapshot creation is best-effort and often fails (e.g. if the user
- * navigates away from the page too soon), and we must be sure to return an old
- * result if a new one does not yet exist.
- */
-static void
-ensure_snapshot_freshness_for_web_view (EphySnapshotService *service,
-                                        WebKitWebView       *web_view)
-{
-  GTask *task;
-  const char *uri;
-
-  uri = webkit_web_view_get_uri (web_view);
-  if (ephy_snapshot_service_lookup_snapshot_freshness (service, uri) != SNAPSHOT_FRESH) {
-    task = g_task_new (service, NULL, NULL, NULL);
-    g_task_set_task_data (task,
-                          snapshot_async_data_new (web_view, time (NULL)),
-                          (GDestroyNotify)snapshot_async_data_free);
-    g_idle_add ((GSourceFunc)ephy_snapshot_service_take_from_webview, task);
-  }
-}
-
 /**
  * ephy_snapshot_service_get_snapshot_async:
  * @service: a #EphySnapshotService
@@ -654,12 +607,11 @@ ephy_snapshot_service_get_snapshot_async (EphySnapshotService *service,
    * the snapshot path is in memory cache; this is an indication that the
    * snapshot is fresh. */
   uri = webkit_web_view_get_uri (web_view);
-  if (uri) {
+  if (uri && ephy_snapshot_service_lookup_snapshot_freshness (service, uri) == SNAPSHOT_FRESH) {
     ephy_snapshot_service_get_snapshot_for_url_async (service,
                                                       uri, mtime, cancellable,
                                                       (GAsyncReadyCallback)got_snapshot_for_url,
                                                       task);
-    ensure_snapshot_freshness_for_web_view (service, web_view);
   } else {
     g_idle_add ((GSourceFunc)ephy_snapshot_service_take_from_webview, task);
   }
@@ -704,58 +656,33 @@ ephy_snapshot_service_get_snapshot_finish (EphySnapshotService *service,
 }
 
 typedef struct {
-  EphySnapshotService *service;
   GdkPixbuf *snapshot;
   char *url;
   time_t mtime;
-  gint refcount;
 } SaveSnapshotAsyncData;
 
 static SaveSnapshotAsyncData *
-save_snapshot_async_data_new (EphySnapshotService *service,
-                              GdkPixbuf           *snapshot,
-                              const char          *url,
-                              time_t               mtime)
+save_snapshot_async_data_new (GdkPixbuf  *snapshot,
+                              const char *url,
+                              time_t      mtime)
 {
   SaveSnapshotAsyncData *data;
 
   data = g_slice_new0 (SaveSnapshotAsyncData);
-  data->service = g_object_ref (service);
   data->snapshot = g_object_ref (snapshot);
   data->url = g_strdup (url);
   data->mtime = mtime;
-  data->refcount = 1;
 
   return data;
 }
 
-static SaveSnapshotAsyncData *
-save_snapshot_async_data_ref (SaveSnapshotAsyncData *data)
-{
-  g_atomic_int_add (&data->refcount, 1);
-  return data;
-}
-
 static void
-save_snapshot_async_data_unref (SaveSnapshotAsyncData *data)
+save_snapshot_async_data_free (SaveSnapshotAsyncData *data)
 {
-  if (g_atomic_int_dec_and_test (&data->refcount)) {
-    g_object_unref (data->service);
-    g_object_unref (data->snapshot);
-    g_free (data->url);
-    g_slice_free (SaveSnapshotAsyncData, data);
-  }
-}
+  g_object_unref (data->snapshot);
+  g_free (data->url);
 
-static gboolean
-idle_emit_snapshot_saved (gpointer user_data)
-{
-  SaveSnapshotAsyncData *data = (SaveSnapshotAsyncData *)user_data;
-
-  g_signal_emit (data->service, signals[SNAPSHOT_SAVED], 0, data->url, data->mtime);
-
-  save_snapshot_async_data_unref (data);
-  return G_SOURCE_REMOVE;
+  g_slice_free (SaveSnapshotAsyncData, data);
 }
 
 static void
@@ -770,9 +697,9 @@ save_snapshot_thread (GTask                 *task,
                                                   data->snapshot,
                                                   data->url,
                                                   data->mtime);
-  g_idle_add (idle_emit_snapshot_saved, save_snapshot_async_data_ref (data));
 
   path = gnome_desktop_thumbnail_path_for_uri (data->url, GNOME_DESKTOP_THUMBNAIL_SIZE_LARGE);
+
   cache_snapshot_data_in_idle (service, data->url, path, SNAPSHOT_FRESH);
 
   g_task_return_pointer (task, path, g_free);
@@ -796,8 +723,8 @@ ephy_snapshot_service_save_snapshot_async (EphySnapshotService *service,
   task = g_task_new (service, cancellable, callback, user_data);
   g_task_set_priority (task, G_PRIORITY_LOW);
   g_task_set_task_data (task,
-                        save_snapshot_async_data_new (service, snapshot, url, mtime),
-                        (GDestroyNotify)save_snapshot_async_data_unref);
+                        save_snapshot_async_data_new (snapshot, url, mtime),
+                        (GDestroyNotify)save_snapshot_async_data_free);
   g_task_run_in_thread (task, (GTaskThreadFunc)save_snapshot_thread);
   g_object_unref (task);
 }
@@ -908,7 +835,7 @@ ephy_snapshot_service_get_snapshot_path_async (EphySnapshotService *service,
   task = g_task_new (service, cancellable, callback, user_data);
 
   uri = webkit_web_view_get_uri (web_view);
-  if (uri) {
+  if (uri && ephy_snapshot_service_lookup_snapshot_freshness (service, uri) == SNAPSHOT_FRESH) {
     const char *path = ephy_snapshot_service_lookup_snapshot_path (service, uri);
 
     if (path) {
@@ -923,8 +850,6 @@ ephy_snapshot_service_get_snapshot_path_async (EphySnapshotService *service,
                                                              (GAsyncReadyCallback)got_snapshot_path_for_url,
                                                              task);
     }
-
-    ensure_snapshot_freshness_for_web_view (service, web_view);
   } else {
     g_task_set_task_data (task,
                           snapshot_async_data_new (web_view, mtime),
