@@ -766,7 +766,6 @@ window_cmd_file_save_as_application (GtkAction  *action,
   GdkPixbuf *pixbuf;
   GtkStyleContext *context;
   char *markup;
-  char *escaped_address;
 
   embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
   g_return_if_fail (embed != NULL);
@@ -815,12 +814,10 @@ window_cmd_file_save_as_application (GtkAction  *action,
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
   gtk_box_pack_start (GTK_BOX (box), entry, FALSE, FALSE, 0);
 
-  escaped_address = g_markup_escape_text (ephy_web_view_get_display_address (view), -1);
-  markup = g_strdup_printf ("<small>%s</small>", escaped_address);
+  markup = g_strdup_printf ("<small>%s</small>", ephy_web_view_get_display_address (view));
   label = gtk_label_new (NULL);
   gtk_label_set_markup (GTK_LABEL (label), markup);
   g_free (markup);
-  g_free (escaped_address);
   gtk_box_pack_end (GTK_BOX (box), label, FALSE, FALSE, 0);
   context = gtk_widget_get_style_context (label);
   gtk_style_context_add_class (context, "dim-label");
@@ -1536,6 +1533,30 @@ void window_cmd_tabs_move_right (GtkAction  *action,
   gtk_notebook_reorder_child (notebook, child, page + 1);
 }
 
+void
+window_cmd_tabs_duplicate (GtkAction  *action,
+                           EphyWindow *window)
+{
+  EphyEmbed *embed, *new_embed;
+  EphyWebView *view, *new_view;
+  WebKitWebViewSessionState *session_state;
+
+  embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
+  view = ephy_embed_get_web_view (embed);
+  session_state = webkit_web_view_get_session_state (WEBKIT_WEB_VIEW (view));
+
+  new_embed = ephy_shell_new_tab (ephy_shell_get_default (),
+                                  window,
+                                  embed,
+                                  EPHY_NEW_TAB_APPEND_AFTER | EPHY_NEW_TAB_JUMP);
+
+  new_view = ephy_embed_get_web_view (new_embed);
+
+  webkit_web_view_restore_session_state (WEBKIT_WEB_VIEW (new_view), session_state);
+  webkit_web_view_session_state_unref (session_state);
+  ephy_web_view_load_url (new_view, webkit_web_view_get_uri (WEBKIT_WEB_VIEW (view)));
+}
+
 void
 window_cmd_tabs_detach (GtkAction  *action,
                         EphyWindow *window)
